==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dijit/_editor/nls/fr/commands.js <==
({
	'bold': 'Gras',
	'copy': 'Copier',
	'cut': 'Couper',
	'delete': 'Supprimer',
	'indent': 'Retrait',
	'insertHorizontalRule': 'Règle horizontale',
	'insertOrderedList': 'Liste numérotée',
	'insertUnorderedList': 'Liste à puces',
	'italic': 'Italique',
	'justifyCenter': 'Aligner au centre',
	'justifyFull': 'Justifier',
	'justifyLeft': 'Aligner à gauche',
	'justifyRight': 'Aligner à droite',
	'outdent': 'Retrait négatif',
	'paste': 'Coller',
	'redo': 'Rétablir',
	'removeFormat': 'Supprimer la mise en forme',
	'selectAll': 'Sélectionner tout',
	'strikethrough': 'Barrer',
	'subscript': 'Indice',
	'superscript': 'Exposant',
	'underline': 'Souligner',
	'undo': 'Annuler',
	'unlink': 'Supprimer le lien',
	'createLink': 'Créer un lien',
	'toggleDir': 'Changer de sens',
	'insertImage': 'Insérer une image',
	'insertTable': 'Insérer/Modifier un tableau',
	'toggleTableBorder': 'Afficher/Masquer la bordure du tableau',
	'deleteTable': 'Supprimer le tableau',
	'tableProp': 'Propriété du tableau',
	'htmlToggle': 'Source HTML',
	'foreColor': 'Couleur avant-plan',
	'hiliteColor': 'Couleur arrière-plan',
	'plainFormatBlock': 'Style de paragraphe',
	'formatBlock': 'Style de paragraphe',
	'fontSize': 'Taille de police',
	'fontName': 'Nom de police',
	'tabIndent': 'Retrait de tabulation',
	"fullScreen": "Basculer vers le mode plein écran",
	"viewSource": "Afficher la source HTML",
	"print": "Imprimer",
	"newPage": "Nouvelle page",
	/* Error messages */
	'systemShortcut': 'Action "${0}" uniquement disponible dans votre navigateur via un raccourci clavier. Utilisez ${1}.'
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dijit/_editor/nls/fr/commands.js <==
define(
//begin v1.x content
({
	'bold': 'Gras',
	'copy': 'Copier',
	'cut': 'Couper',
	'delete': 'Supprimer',
	'indent': 'Retrait',
	'insertHorizontalRule': 'Règle horizontale',
	'insertOrderedList': 'Liste numérotée',
	'insertUnorderedList': 'Liste à puces',
	'italic': 'Italique',
	'justifyCenter': 'Aligner au centre',
	'justifyFull': 'Justifier',
	'justifyLeft': 'Aligner à gauche',
	'justifyRight': 'Aligner à droite',
	'outdent': 'Retrait négatif',
	'paste': 'Coller',
	'redo': 'Rétablir',
	'removeFormat': 'Supprimer la mise en forme',
	'selectAll': 'Sélectionner tout',
	'strikethrough': 'Barrer',
	'subscript': 'Indice',
	'superscript': 'Exposant',
	'underline': 'Souligner',
	'undo': 'Annuler',
	'unlink': 'Supprimer le lien',
	'createLink': 'Créer un lien',
	'toggleDir': 'Changer de sens',
	'insertImage': 'Insérer une image',
	'insertTable': 'Insérer/Modifier un tableau',
	'toggleTableBorder': 'Afficher/Masquer la bordure du tableau',
	'deleteTable': 'Supprimer le tableau',
	'tableProp': 'Propriété du tableau',
	'htmlToggle': 'Source HTML',
	'foreColor': 'Couleur d\'avant-plan',
	'hiliteColor': 'Couleur d\'arrière-plan',
	'plainFormatBlock': 'Style de paragraphe',
	'formatBlock': 'Style de paragraphe',
	'fontSize': 'Taille de police',
	'fontName': 'Nom de police',
	'tabIndent': 'Retrait de tabulation',
	"fullScreen": "Basculer en plein écran",
	"viewSource": "Afficher la source HTML",
	"print": "Imprimer",
	"newPage": "Nouvelle page",
	/* Error messages */
	'systemShortcut': 'L\'action "${0}" est disponible dans votre navigateur uniquement, par le biais d\'un raccourci-clavier. Utilisez ${1}.'
})
//end v1.x content
);
